/**********************************************************************/
/*  Distill.CMD                                                       */
/*  -----------                                                       */
/*  This REXX routine will take a raw postscript file and feed it     */
/*  through Aladdin Ghostscript in order to produce an Acrobat        */
/*  Portable Document Format (PDF) file.  Input is the file name of   */
/*  the raw postscript file.  If input is specified as "STDIN" it     */
/*  will accept the input from the STDIN device.  This makes it       */
/*  possible to use this REXX program with Kai Uwe Rommel's freeware  */
/*  PRINTMON program to produce Acrobat documents on the fly.         */
/*                                                                    */
/*  To use this program with PRINTMON to produce Acrobat documents    */
/*  directly, you must create a Printer object using the Generic      */
/*  Postscript Printer driver for OS/2.  For best results, always     */
/*  use the latest Postscript printer driver from IBM (at this        */
/*  writing, it is 30.515).  Assign the printer to a port (for        */
/*  example, LPT3).                                                   */
/*                                                                    */
/*  Next, add the following line to your STARTUP.CMD file:            */
/*                                                                    */
/*      START /MIN PRINTMON LPTx "Distill STDIN"                      */
/*                                                                    */
/*  (The above assumes that PRINTMON.EXE and DISTILL.CMD are in your  */
/*  path).  Whenever you print to the Postscript printer object, a    */
/*  pop-up dialog box should appear prompting you for a file name     */
/*  for your document.  Enter the name and press the "OK" button.     */
/*  That's all there is to it!                                        */
/*                                                                    */
/*  Requirements:                                                     */
/*     PRINTMON.EXE                                                   */
/*     Aladdin Ghostscript                                            */
/*     Postscript Printer object                                      */
/*     IBM EWS Visual REXX Extensions (VREXX)                         */
/*     EMX Run Time environment                                       */
/*     Adobe's Acrobat Reader for OS/2                                */
/**********************************************************************/
'@ECHO OFF'
gsdir = 'C:\gstools\gs5.01'     /* Directory where Ghostscript lives  */
acdir = 'C:\AcroRead'           /* Directory for Adobe Acrobat Reader */

/**********************************************************************/
/*  Parse the input file name.  If STDIN, set up so Ghostscript will  */
/*  read from STDIN and create a PDF file with a default name in the  */
/*  temporary directory.  Otherwise, parse the file name and use it   */
/*  as the default name for the PDF document.                         */
/**********************************************************************/
Parse Arg input
If Translate(input) = 'STDIN' Then
   Do
      psname = '-'
      psfn = 'DOCUMENT'
   End
Else
   Do
      psname = Filespec('N', input)
      period = Pos('.', psname)
      If period \= 0 Then
         Parse Value psname With psfn '.' .
      Else
         psfn = psname
      If psname = input Then
         Do
            path = Directory()
            path = Strip(path, 'T', '\')
            psname = path || '\' || psname
         End
   End

/**********************************************************************/
/*  set up the environment for the IBM EWS VREXX extensions, then     */
/*  prompt the user for the name of the new Acrobat document.  Once   */
/*  received, cancel the VREXX environment.                           */
/**********************************************************************/
Call RxFuncAdd 'VInit', 'VREXX', 'VINIT'
initcode = VInit()
If initcode \= 'ERROR' Then
   Do
      Call VDialogPos 50, 50
      prompt.0 = 2
      prompt.1 = 'Enter Path and Filename   '
      prompt.2 = '       for PDF document   '
      prompt.vstring = Value('TEMP', , 'OS2ENVIRONMENT') || ,
                       '\' || psfn || '.PDF'
      Call VInputBox 'Ghostscript Distiller', ,
                     'PROMPT', ,
                     44, ,
                     1
      pdfname = prompt.vstring

/**********************************************************************/
/*  Switch to the Ghostscript directory and use Ghostscript to        */
/*  distill the raw postscript file into PDF format.  When done,      */
/*  return to the home directory.                                     */
/**********************************************************************/
      Call Directory gsdir
      'GS -q -dNOPAUSE -dBATCH -sDEVICE#pdfwrite -sOutputFile#' || ,
         pdfname psname
      Call Directory path

/**********************************************************************/
/*  If the PDF file was created, prompt the user to see if he wants   */
/*  to launch the Acrobat Reader to verify its validity.              */
/**********************************************************************/
      If Stream(pdfname, 'C', 'QUERY EXISTS') \= '' Then
         Do
            prompt.0 = 1
            prompt.1 = 'View the document?   '
            If VMsgBox('Launch Acrobat', 'PROMPT', 6) = 'YES' Then
               'START' acdir || ,
                       '\ACROREAD' ,
                       pdfname
         End
      Call VExit
   End
Exit
